@@ -1575,7 +1575,7 @@ if (fabs(mol->envi_sdm.at(i).d-sqrt(Distance(p0,ppc)))>0.5){
 }
 
 void ChGL::paintGL(){
-  //if (pause)  return;
+  if (pause)  return;
   warLabel = drawLa;
   GLfloat fgc[4]={(GLfloat)backGroundColor.redF(),(GLfloat)backGroundColor.greenF(),(GLfloat)backGroundColor.blueF(),1.0};
   glFogfv(GL_FOG_COLOR,fgc);
